/**
 * Utility functions for ticket ID handling
 * Supports both local format (0001) and GitHub format (#1, 1)
 */
export declare class IDUtils {
    /**
     * Check if a ticket ID is valid
     * Accepts:
     * - Local format: 4-digit numbers (0001, 0042, 1234)
     * - GitHub format: #1-9999 or 1-9999
     */
    static isValidTicketId(id: string): boolean;
    /**
     * Normalize ticket ID by removing # prefix for GitHub IDs
     * Local IDs remain unchanged
     */
    static normalizeTicketId(id: string): string;
    /**
     * Detect ID format
     * Returns 'local', 'github', or null
     */
    static getIdFormat(id: string): 'local' | 'github' | null;
    /**
     * Format ticket ID for display
     * Local: 0001
     * GitHub: #1
     */
    static formatTicketId(id: string | number, lengthOrFormat?: number | 'local' | 'github'): string;
}
