/**
 * Multi-agent code review command guide template
 * Provides structured approach for comprehensive code reviews using Claude and Gemini
 */
export declare const codeReviewTemplate = "# Multi-Agent Code Review\n\nPerform comprehensive code reviews using multiple AI perspectives.\n\n## Review Process\n\n### Step 1: Correctness Review (Claude)\nReview the current changes for correctness:\n- Logic errors and bugs\n- Edge case handling\n- Adherence to requirements\n- Code consistency\n\n### Step 2: Performance Review (Gemini)\nSwitch to terminal and run:\n```bash\ngemini -p \"@src/ @tests/ Review these changes for performance:\n\nFocus on:\n- Algorithm efficiency\n- Database query optimization\n- Memory usage patterns\n- Potential bottlenecks\n- Async/await optimization\"\n```\n\n### Step 3: Security Review (Claude)\nReview the changes for security issues:\n- Input validation\n- Authentication/authorization\n- SQL injection risks\n- XSS vulnerabilities\n- Sensitive data exposure\n- Dependency vulnerabilities\n\n### Step 4: Synthesize Results\nCreate a summary that includes:\n1. Critical issues from all reviews\n2. Conflicting recommendations (if any)\n3. Priority-ordered action items\n4. Overall assessment\n\n### Step 5: Prioritize and Select Issues for Ticketing\n\nCategorize findings by priority:\n\n**\uD83D\uDD34 Critical (Immediate Action Required):**\n- Security vulnerabilities that expose data\n- Logic errors causing system failure\n- Performance issues blocking user experience\n\n**\uD83D\uDFE1 Important (Should Address Soon):**\n- Code maintainability improvements\n- Minor performance optimizations  \n- Non-critical security hardening\n\n**\uD83D\uDFE2 Optional (Nice to Have):**\n- Style consistency improvements\n- Documentation updates\n- Refactoring for readability\n\n**Next Steps - Please Select:**\n\n1. **Which issues would you like to create tickets for?**\n   \n   **Recommendations:**\n   - \u2705 Create tickets for ALL Critical issues (strongly recommended)\n   - \u2753 Create tickets for selected Important issues (your choice based on timeline)  \n   - \u2753 Create tickets for Optional issues (only if time permits)\n\n2. **Your Decision:**\n   Review the prioritized list above and answer:\n   - Do you want to ticket all Critical issues? (Y/N)\n   - Which Important issues deserve tickets? (list specific ones)\n   - Any Optional issues you want to address? (list if any)\n\n3. **Create tickets based on your selection:**\n```bash\n# For your selected issues only:\nait3 ticket create \"Fix security vulnerability: [specific issue you chose]\"\nait3 ticket create \"Optimize performance: [specific bottleneck you selected]\"\nait3 ticket create \"Refactor code: [specific improvement you want]\"\n\n# Optional: Document review completion\ngit add .\ngit commit -m \"review(#TICKET): completed multi-agent code review\n\nSelected findings documented as tickets for implementation\"\n```\n\n**Key Question: What would you like to focus on first?**\n\n## Quick Commands\n\nFor specific review types:\n```bash\n# Performance only\ngemini -p \"@src/ Review this code for performance bottlenecks\"\n\n# Security only  \n# In Claude: \"Review this code for security vulnerabilities\"\n\n# Architecture review\ngemini -p \"@src/ @docs/ Is this architecture scalable and maintainable?\"\n```\n\n## Tips\n- Run reviews after GREEN phase, before REFACTOR\n- Document conflicting opinions in commit messages\n- Keep context focused on specific changes\n- Use ticket scope to limit review scope\n";
