/**
 * AIT³ methodology template content
 */
export declare const AIT3_METHODOLOGY_TEMPLATE = "\n\n## AIT\u00B3 Development Methodology\n\nAIT\u00B3 (AI + Ticket + Test + Tool driven development) implements a disciplined workflow:\n\n### Workflow Phases\n1. **PLANNING** - Dialectical reasoning with Claude and Gemini\n2. **RED** - Test-first development (0% pass rate)\n3. **GREEN** - Minimal implementation (100% pass rate)\n4. **REFACTOR** - Code optimization (maintain 100% tests)\n5. **SQUASH** - Git history cleanup\n\n### Core Principles\n- Claude proposes \u2192 Gemini challenges \u2192 Human decides\n- Tests define behavior, not implementation\n- 100% test pass rate before refactoring\n- Create tickets for mock implementations\n- Pure functions with service injection\n\n### Commands\n```bash\n# Ticket management\nait3 ticket create \"Feature name\"\nait3 ticket start <id>\nait3 ticket complete <id>\n\n# AIT\u00B3 workflow\nait3 flow plan <ticketId>\nait3 flow red <ticketId>\nait3 flow green <ticketId>\nait3 flow refactor <ticketId>\nait3 flow squash <ticketId>\n```\n";
/**
 * Multi-agent review command guide template
 */
export declare const REVIEW_COMMAND_TEMPLATE = "# Multi-Agent Code Review\n\nPerform comprehensive code reviews using multiple AI perspectives.\n\n## Review Process\n\n### Step 1: Correctness Review (Claude)\nReview the current changes for correctness:\n- Logic errors and bugs\n- Edge case handling\n- Adherence to requirements\n- Code consistency\n\n### Step 2: Performance Review (Gemini)\nSwitch to terminal and run:\n```bash\ngemini -p \"@src/ @tests/ Review these changes for performance:\n\nFocus on:\n- Algorithm efficiency\n- Database query optimization\n- Memory usage patterns\n- Potential bottlenecks\n- Async/await optimization\"\n```\n\n### Step 3: Security Review (Claude)\nReview the changes for security issues:\n- Input validation\n- Authentication/authorization\n- SQL injection risks\n- XSS vulnerabilities\n- Sensitive data exposure\n- Dependency vulnerabilities\n\n### Step 4: Synthesize Results\nCreate a summary that includes:\n1. Critical issues from all reviews\n2. Conflicting recommendations (if any)\n3. Priority-ordered action items\n4. Overall assessment\n\n### Step 5: Document Decision\nAfter human review, document the decision:\n```bash\ngit add .\ngit commit -m \"review(#TICKET): implement review feedback\n\nCorrectness: [summary of fixes]\nPerformance: [optimizations made]\nSecurity: [vulnerabilities addressed]\n\nHuman decision: [rationale for choices made]\"\n```\n\n## Quick Commands\n\nFor specific review types:\n```bash\n# Performance only\ngemini -p \"@src/ Review this code for performance bottlenecks\"\n\n# Security only  \n# In Claude: \"Review this code for security vulnerabilities\"\n\n# Architecture review\ngemini -p \"@src/ @docs/ Is this architecture scalable and maintainable?\"\n```\n\n## Tips\n- Run reviews after GREEN phase, before REFACTOR\n- Document conflicting opinions in commit messages\n- Keep context focused on specific changes\n- Use ticket scope to limit review scope\n";
/**
 * ait3-init command guide template
 */
export declare const AIT3_INIT_GUIDE_TEMPLATE = "# Initialize Complete CLAUDE.md\n\nThis command integrates AIT\u00B3 methodology with your project-specific analysis.\n\n## Instructions\n\n### Step 1: Security Settings (Optional but Recommended)\nIf you want to restrict certain commands for security:\n```bash\nait3 install security\n```\nThis will update your .claude/settings.local.json with:\n- Deny: curl, wget, rm\n- Allow: grep, rg, ls, find (implicitly)\n\n### Step 2: Analyze and Generate CLAUDE.md\n1. Read CLAUDE.ait3.md for AIT\u00B3 template and project analysis\n2. Read .claude/CLAUDE.md for current minimal version  \n3. Analyze the project structure deeply\n4. Generate comprehensive CLAUDE.md that:\n   - Incorporates AIT\u00B3 methodology from the template\n   - Includes project-specific details and analysis\n   - Maintains the philosophical approach of AIT\u00B3\n   - Adds any additional context from your analysis\n\n### Step 3: Cleanup\nDelete CLAUDE.ait3.md as it's no longer needed:\n```bash\nrm CLAUDE.ait3.md\n```\n\n## Key Sections to Include\n- Project overview with AIT\u00B3 context\n- Architecture and technology stack\n- Development methodology (AIT\u00B3 workflow)\n- Testing strategy and requirements\n- AI collaboration patterns\n- Project-specific guidelines\n\nAfter generation, the CLAUDE.ait3.md file can be safely deleted.\n";
